#include <curl/curl.h>
#include <iostream>
#include <vector>
#include "histogram.h"
#include "text.h"
#include "svg.h"

struct Input
{
    std::vector<double> numbers;
    size_t bin_count{};
};

Input input_data(std::istream& in, bool prompt)
{
    Input data;
    size_t number_count;

    if(prompt)
    {
        cerr << "Enter the number of elements: ";
    }

    in >> number_count;
    data.numbers.resize(number_count);

    if(prompt)
    {
        cerr << "\nEnter " << number_count << " elements:" << endl;
    }

    for (size_t i = 0; i < number_count; i++)
    {
        in >> data.numbers[i];
    }
    if(prompt)
    {
        cerr << "Enter the number of bins: ";
    }

    in >> data.bin_count;

    return data;
}

int main(int argc, char* argv[])
{
    curl_global_init(CURL_GLOBAL_ALL);
    using namespace std;

    if (argc > 1)
    {
        const char *url = argv[1];

        CURL *curl = curl_easy_init();
                if (curl) {
            curl_easy_setopt(curl, CURLOPT_URL, url);
            curl_easy_perform(curl);

            CURLcode res = curl_easy_perform(curl);
            if (res != CURLE_OK) {
                cerr << "curl_easy_perform() failed: " << curl_easy_strerror(res) << endl;
                exit(1);
            }

            curl_easy_cleanup(curl);
        }

        return 0;
    }

    auto in = input_data(cin,true);
    auto bins = make_histogram(in.bin_count, in.numbers);
    show_histogram_svg(bins);
    return 0;
}
